#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# Fenrir TTY screen reader
# By Chrys, Storm Dragon, and contributers.

from fenrirscreenreader.core import debug
import re

class command():
    def __init__(self):
        pass
        
    def initialize(self, environment):
        self.env = environment
        # Use commandBuffer like other commands
        if 'silenceUntilPrompt' not in self.env['commandBuffer']:
            self.env['commandBuffer']['silenceUntilPrompt'] = False
        
    def shutdown(self):
        pass
        
    def getDescription(self):
        return _('Toggle speech silence until shell prompt returns')
        
    def run(self):
        if self.env['commandBuffer']['silenceUntilPrompt']:
            self.disableSilence()
        else:
            self.enableSilence()
            
    def enableSilence(self):
        self.env['commandBuffer']['silenceUntilPrompt'] = True
        self.env['runtime']['outputManager'].presentText(_("Speech silenced until prompt returns"), soundIcon='SpeechOff', interrupt=True)
        # Disable speech but don't use the normal temp disable that reactivates on keypress
        self.env['runtime']['settingsManager'].setSetting('speech', 'enabled', 'False')
        
    def disableSilence(self):
        self.env['commandBuffer']['silenceUntilPrompt'] = False
        # Re-enable speech
        self.env['runtime']['settingsManager'].setSetting('speech', 'enabled', 'True')
        self.env['runtime']['outputManager'].presentText(_("Speech restored"), soundIcon='SpeechOn', interrupt=True)
        
    def checkForPrompt(self, text):
        """Check if the current line contains a shell prompt pattern"""
        if not self.env['commandBuffer']['silenceUntilPrompt']:
            return False
            
        # Look for common shell prompt patterns
        # $ prompt (user)
        # # prompt (root)  
        # > prompt (some shells)
        # Also check for common prompt prefixes like user@host:path$
        promptPatterns = [
            r'[^$]*\$$',  # Ends with $ (user prompt)
            r'[^#]*#$',   # Ends with # (root prompt)
            r'[^>]*>$',   # Ends with > (some shells)
            r'.*[\w@]+:.*[$#>]\s*$',  # user@host:path$ style
        ]
        
        for pattern in promptPatterns:
            if re.search(pattern, text.strip()):
                self.disableSilence()
                return True
                
        return False
        
    def setCallback(self, callback):
        pass